@@ -11,7 +11,7 @@ def vine_download(url, output_dir='.', merge=True, info_only=False):
     title1 = r1(r'<meta property="twitter:title" content="([^"]*)"', html)
     title2 = r1(r'<meta property="twitter:description" content="([^"]*)"', html)
     title = "%s - %s" % (title1, title2) + " [" + vid + "]"
-    url = r1(r'<source src="([^"]*)"', html) or r1(r'<meta itemprop="contentURL" content="([^"]*)"', html)
+    url = r1(r'<source src="([^"]*)"', html) or r1(r'<meta itemprop="contentUrl" content="([^"]*)"', html)
     if url[0:2] == "//":
         url = "http:" + url
     type, ext, size = url_info(url)
